@@ -19,25 +19,25 @@
 #endif
 
 DynamicTreeModel::DynamicTreeModel(QObject *parent)
-    : QAbstractItemModel(parent),
-      nextId(1)
+    : QAbstractItemModel(parent)
+    , nextId(1)
 {
 }
 
 QModelIndex DynamicTreeModel::index(int row, int column, const QModelIndex &parent) const
 {
-//   if (column != 0)
-//     return QModelIndex();
+    //   if (column != 0)
+    //     return QModelIndex();
 
     if (column < 0 || row < 0) {
         return QModelIndex();
     }
 
-    QList<QList<qint64> > childIdColumns = m_childItems.value(parent.internalId());
+    QList<QList<qint64>> childIdColumns = m_childItems.value(parent.internalId());
 
     const qint64 grandParent = findParentId(parent.internalId());
     if (grandParent >= 0) {
-        QList<QList<qint64> > parentTable = m_childItems.value(grandParent);
+        QList<QList<qint64>> parentTable = m_childItems.value(grandParent);
         Q_ASSERT(parent.column() < parentTable.size());
         QList<qint64> parentSiblings = parentTable.at(parent.column());
         Q_ASSERT(parent.row() < parentSiblings.size());
@@ -60,7 +60,6 @@ QModelIndex DynamicTreeModel::index(int row, int column, const QModelIndex &pare
     qint64 id = rowIds.at(row);
 
     return createIndex(row, column, reinterpret_cast<void *>(id));
-
 }
 
 qint64 DynamicTreeModel::findParentId(qint64 searchId) const
@@ -69,10 +68,10 @@ qint64 DynamicTreeModel::findParentId(qint64 searchId) const
         return -1;
     }
 
-    QHashIterator<qint64, QList<QList<qint64> > > i(m_childItems);
+    QHashIterator<qint64, QList<QList<qint64>>> i(m_childItems);
     while (i.hasNext()) {
         i.next();
-        QListIterator<QList<qint64> > j(i.value());
+        QListIterator<QList<qint64>> j(i.value());
         while (j.hasNext()) {
             QList<qint64> l = j.next();
             if (l.contains(searchId)) {
@@ -107,12 +106,11 @@ QModelIndex DynamicTreeModel::parent(const QModelIndex &index) const
     int row = childList.indexOf(parentId);
 
     return createIndex(row, column, reinterpret_cast<void *>(parentId));
-
 }
 
 int DynamicTreeModel::rowCount(const QModelIndex &index) const
 {
-    QList<QList<qint64> > cols = m_childItems.value(index.internalId());
+    QList<QList<qint64>> cols = m_childItems.value(index.internalId());
 
     if (cols.size() == 0) {
         return 0;
@@ -127,7 +125,7 @@ int DynamicTreeModel::rowCount(const QModelIndex &index) const
 
 int DynamicTreeModel::columnCount(const QModelIndex &index) const
 {
-//   Q_UNUSED(index);
+    //   Q_UNUSED(index);
     return m_childItems.value(index.internalId()).size();
 }
 
@@ -173,12 +171,12 @@ bool DynamicTreeModel::dropMimeData(const QMimeData *data, Qt::DropAction action
     Q_UNUSED(_column);
     QByteArray encoded = data->data(mimeTypes().at(0));
 
-    QHash<QModelIndex, QList<int> > movedItems;
+    QHash<QModelIndex, QList<int>> movedItems;
     bool ok;
     qint64 id;
     int _row;
     static const int column = 0;
-    QHash<qint64, QList<QList<qint64> > >::const_iterator it;
+    QHash<qint64, QList<QList<qint64>>>::const_iterator it;
     const auto lst = encoded.split('\0');
     for (const QByteArray &ba : lst) {
         id = ba.toInt(&ok);
@@ -207,7 +205,7 @@ bool DynamicTreeModel::dropMimeData(const QMimeData *data, Qt::DropAction action
 
     QList<int> srcPath;
     QModelIndex srcParent;
-    QHash<QModelIndex, QList<int> >::iterator src_parent_it = movedItems.begin();
+    QHash<QModelIndex, QList<int>>::iterator src_parent_it = movedItems.begin();
     int startRow = 0;
     int endRow = 0;
     int nextMovedRow = 0;
@@ -248,7 +246,6 @@ bool DynamicTreeModel::dropMimeData(const QMimeData *data, Qt::DropAction action
                 if ((src_row_it + 1) == rows_moved_end) {
                     moveCommands.prepend(getMoveCommand(srcPath, startRow, endRow));
                 }
-
             }
         }
     }
@@ -266,7 +263,7 @@ bool DynamicTreeModel::dropMimeData(const QMimeData *data, Qt::DropAction action
     }
 
     int offset = firstCommand->endRow() - firstCommand->startRow() + 1;
-    for (ModelMoveCommand *moveCommand : qAsConst(moveCommands)) {
+    for (ModelMoveCommand *moveCommand : std::as_const(moveCommands)) {
         moveCommand->setDestAncestors(indexToPath(destParent));
         moveCommand->setDestRow(destRowIndex.row() + offset);
         moveCommand->doCommand();
@@ -343,14 +340,14 @@ QModelIndexList DynamicTreeModel::match(const QModelIndex &start, int role, cons
     qint64 id = value.toLongLong();
     if (role == Qt::DisplayRole) {
         id = m_items.key(value.toString());
-      }
+    }
 
-    QHash<qint64, QList<QList<qint64> > >::const_iterator it = m_childItems.constBegin();
-    const QHash<qint64, QList<QList<qint64> > >::const_iterator end = m_childItems.constEnd();
+    QHash<qint64, QList<QList<qint64>>>::const_iterator it = m_childItems.constBegin();
+    const QHash<qint64, QList<QList<qint64>>>::const_iterator end = m_childItems.constEnd();
 
-    QList<QList<qint64> > items;
-    QList<QList<qint64> >::const_iterator itemIt;
-    QList<QList<qint64> >::const_iterator itemEnd;
+    QList<QList<qint64>> items;
+    QList<QList<qint64>>::const_iterator itemIt;
+    QList<QList<qint64>>::const_iterator itemEnd;
     int foundIndexRow;
     for (; it != end; ++it) {
         items = it.value();
@@ -367,9 +364,12 @@ QModelIndexList DynamicTreeModel::match(const QModelIndex &start, int role, cons
 }
 
 ModelChangeCommand::ModelChangeCommand(DynamicTreeModel *model, QObject *parent)
-    : QObject(parent), m_model(model), m_startRow(-1), m_endRow(-1), m_numCols(1)
+    : QObject(parent)
+    , m_model(model)
+    , m_startRow(-1)
+    , m_endRow(-1)
+    , m_numCols(1)
 {
-
 }
 
 QModelIndex ModelChangeCommand::findIndex(const QList<int> &rows) const
@@ -387,7 +387,6 @@ QModelIndex ModelChangeCommand::findIndex(const QList<int> &rows) const
 ModelInsertCommand::ModelInsertCommand(DynamicTreeModel *model, QObject *parent)
     : ModelChangeCommand(model, parent)
 {
-
 }
 
 QList<ModelInsertCommand::Token> ModelInsertCommand::tokenize(const QString &treeString) const
@@ -485,7 +484,6 @@ void ModelInsertCommand::doCommand()
 
                 m_model->m_items.insert(id, name);
                 m_model->m_childItems[parentId][col].insert(row, id);
-
             }
         }
     }
@@ -538,11 +536,17 @@ void ModelInsertCommand::doInsertTree(const QModelIndex &fragmentParent)
         id = m_model->newId();
         lastId = id;
         for (int column = 0; column < m_numCols; ++column) {
-            if (m_model->m_childItems[fragmentParentIdentifier].size() <= column) {
-                m_model->m_childItems[fragmentParentIdentifier].append(QList<qint64>());
+            QList<QList<qint64>> &children = m_model->m_childItems[fragmentParentIdentifier];
+            if (children.size() <= column) {
+                children.append(QList<qint64>());
             }
             m_model->m_items.insert(id, QString::number(id));
-            m_model->m_childItems[fragmentParentIdentifier][column].insert(rows[depth], id);
+            const int rowForDepth = rows[depth];
+            if (rowForDepth >= children[column].size()) {
+                children[column].append(id);
+            } else {
+                children[column].insert(rowForDepth, id);
+            }
             if (column != m_numCols - 1) {
                 id = m_model->newId();
             }
@@ -579,7 +583,7 @@ void ModelInsertAndRemoveQueuedCommand::queuedEndRemoveRows()
 
 void ModelInsertAndRemoveQueuedCommand::purgeItem(qint64 parent)
 {
-    QList<QList<qint64> > childItemRows = m_model->m_childItems.value(parent);
+    QList<QList<qint64>> childItemRows = m_model->m_childItems.value(parent);
 
     if (!childItemRows.isEmpty()) {
         for (int col = 0; col < m_numCols; col++) {
@@ -597,13 +601,13 @@ void ModelInsertAndRemoveQueuedCommand::doCommand()
 {
     QModelIndex parent = findIndex(m_rowNumbers);
 
-    connect(this, SIGNAL(beginInsertRows(QModelIndex,int,int)), SLOT(queuedBeginInsertRows(QModelIndex,int,int)), Qt::QueuedConnection);
-    connect(this, SIGNAL(endInsertRows()), SLOT(queuedEndInsertRows()), Qt::QueuedConnection);
-    connect(this, SIGNAL(beginRemoveRows(QModelIndex,int,int)), SLOT(queuedBeginRemoveRows(QModelIndex,int,int)), Qt::QueuedConnection);
-    connect(this, SIGNAL(endRemoveRows()), SLOT(queuedEndRemoveRows()), Qt::QueuedConnection);
+    connect(this, &ModelInsertAndRemoveQueuedCommand::beginInsertRows, this, &ModelInsertAndRemoveQueuedCommand::queuedBeginInsertRows, Qt::QueuedConnection);
+    connect(this, &ModelInsertAndRemoveQueuedCommand::endInsertRows, this, &ModelInsertAndRemoveQueuedCommand::queuedEndInsertRows, Qt::QueuedConnection);
+    connect(this, &ModelInsertAndRemoveQueuedCommand::beginRemoveRows, this, &ModelInsertAndRemoveQueuedCommand::queuedBeginRemoveRows, Qt::QueuedConnection);
+    connect(this, &ModelInsertAndRemoveQueuedCommand::endRemoveRows, this, &ModelInsertAndRemoveQueuedCommand::queuedEndRemoveRows, Qt::QueuedConnection);
 
     Q_EMIT beginInsertRows(parent, m_startRow, m_endRow);
-//   m_model->beginInsertRows(parent, m_startRow, m_endRow);
+    //   m_model->beginInsertRows(parent, m_startRow, m_endRow);
     qint64 parentId = parent.internalId();
     for (int row = m_startRow; row <= m_endRow; row++) {
         for (int col = 0; col < m_numCols; col++) {
@@ -615,15 +619,14 @@ void ModelInsertAndRemoveQueuedCommand::doCommand()
 
             m_model->m_items.insert(id, name);
             m_model->m_childItems[parentId][col].insert(row, id);
-
         }
     }
 
     Q_EMIT endInsertRows();
-//   m_model->endInsertRows();
+    //   m_model->endInsertRows();
 
     Q_EMIT beginRemoveRows(parent, m_startRow, m_endRow);
-//   m_model->beginRemoveRows(parent, m_startRow, m_endRow);
+    //   m_model->beginRemoveRows(parent, m_startRow, m_endRow);
     for (int col = 0; col < m_numCols; col++) {
         QList<qint64> childItems = m_model->m_childItems.value(parentId).value(col);
         for (int row = m_startRow; row <= m_endRow; row++) {
@@ -633,14 +636,12 @@ void ModelInsertAndRemoveQueuedCommand::doCommand()
         }
     }
     Q_EMIT endRemoveRows();
-//   m_model->endRemoveRows();
-
+    //   m_model->endRemoveRows();
 }
 
 ModelRemoveCommand::ModelRemoveCommand(DynamicTreeModel *model, QObject *parent)
     : ModelChangeCommand(model, parent)
 {
-
 }
 
 void ModelRemoveCommand::doCommand()
@@ -661,7 +662,7 @@ void ModelRemoveCommand::doCommand()
 
 void ModelRemoveCommand::purgeItem(qint64 parent)
 {
-    const QList<QList<qint64> > childItemRows = m_model->m_childItems.value(parent);
+    const QList<QList<qint64>> childItemRows = m_model->m_childItems.value(parent);
 
     if (!childItemRows.isEmpty()) {
         for (int col = 0; col < m_numCols; col++) {
@@ -676,9 +677,9 @@ void ModelRemoveCommand::purgeItem(qint64 parent)
 }
 
 ModelDataChangeCommand::ModelDataChangeCommand(DynamicTreeModel *model, QObject *parent)
-    : ModelChangeCommand(model, parent), m_startColumn(0)
+    : ModelChangeCommand(model, parent)
+    , m_startColumn(0)
 {
-
 }
 
 void ModelDataChangeCommand::doCommand()
@@ -687,7 +688,7 @@ void ModelDataChangeCommand::doCommand()
     QModelIndex topLeft = m_model->index(m_startRow, m_startColumn, parent);
     QModelIndex bottomRight = m_model->index(m_endRow, m_numCols - 1, parent);
 
-    QList<QList<qint64> > childItems = m_model->m_childItems[parent.internalId()];
+    QList<QList<qint64>> childItems = m_model->m_childItems[parent.internalId()];
 
     for (int col = m_startColumn; col < m_startColumn + m_numCols; col++) {
         for (int row = m_startRow; row <= m_endRow; row++) {
@@ -701,7 +702,6 @@ void ModelDataChangeCommand::doCommand()
 ModelMoveCommand::ModelMoveCommand(DynamicTreeModel *model, QObject *parent)
     : ModelChangeCommand(model, parent)
 {
-
 }
 
 bool ModelMoveCommand::emitPreSignal(const QModelIndex &srcParent, int srcStart, int srcEnd, const QModelIndex &destParent, int destRow)
@@ -736,7 +736,6 @@ void ModelMoveCommand::doCommand()
         }
 
         for (const qint64 id : l) {
-
             if (!m_model->m_childItems.contains(destParent.internalId())) {
                 m_model->m_childItems[destParent.internalId()].append(QList<qint64>());
             }
@@ -753,14 +752,13 @@ void ModelMoveCommand::emitPostSignal()
     m_model->endMoveRows();
 }
 
-ModelMoveLayoutChangeCommand::ModelMoveLayoutChangeCommand(DynamicTreeModel *model, QObject *parent): ModelMoveCommand(model, parent)
+ModelMoveLayoutChangeCommand::ModelMoveLayoutChangeCommand(DynamicTreeModel *model, QObject *parent)
+    : ModelMoveCommand(model, parent)
 {
-
 }
 
 ModelMoveLayoutChangeCommand::~ModelMoveLayoutChangeCommand()
 {
-
 }
 
 bool ModelMoveLayoutChangeCommand::emitPreSignal(const QModelIndex &srcParent, int srcStart, int srcEnd, const QModelIndex &destParent, int destRow)
@@ -848,18 +846,15 @@ void ModelMoveLayoutChangeCommand::emitPostSignal()
     m_model->changePersistentIndexList(m_beforeMoveList, afterMoveList);
     m_beforeMoveList.clear();
     m_model->layoutChanged();
-
 }
 
 ModelResetCommand::ModelResetCommand(DynamicTreeModel *model, QObject *parent)
     : ModelChangeCommand(model, parent)
 {
-
 }
 
 ModelResetCommand::~ModelResetCommand()
 {
-
 }
 
 void ModelResetCommand::setInitialTree(const QString &treeString)
@@ -873,10 +868,10 @@ void ModelResetCommand::doCommand()
     bool blocked = m_model->blockSignals(true);
     m_model->clear();
     if (!m_treeString.isEmpty()) {
-        ModelInsertCommand *ins = new ModelInsertCommand(m_model);
-        ins->setStartRow(0);
-        ins->interpret(m_treeString);
-        ins->doCommand();
+        ModelInsertCommand ins(m_model);
+        ins.setStartRow(0);
+        ins.interpret(m_treeString);
+        ins.doCommand();
     }
     m_model->blockSignals(blocked);
     m_model->endResetModel();
@@ -885,12 +880,10 @@ void ModelResetCommand::doCommand()
 ModelLayoutChangeCommand::ModelLayoutChangeCommand(DynamicTreeModel *model, QObject *parent)
     : ModelChangeCommand(model, parent)
 {
-
 }
 
 ModelLayoutChangeCommand::~ModelLayoutChangeCommand()
 {
-
 }
 
 void ModelLayoutChangeCommand::setInitialTree(const QString &treeString)
@@ -898,7 +891,7 @@ void ModelLayoutChangeCommand::setInitialTree(const QString &treeString)
     m_treeString = treeString;
 }
 
-void ModelLayoutChangeCommand::setPersistentChanges(const QList< ModelLayoutChangeCommand::PersistentChange > &changes)
+void ModelLayoutChangeCommand::setPersistentChanges(const QList<ModelLayoutChangeCommand::PersistentChange> &changes)
 {
     m_changes = changes;
 }
@@ -908,7 +901,7 @@ void ModelLayoutChangeCommand::doCommand()
     m_model->layoutAboutToBeChanged();
     QModelIndexList oldList;
 
-    for (const PersistentChange &change : qAsConst(m_changes)) {
+    for (const PersistentChange &change : std::as_const(m_changes)) {
         const IndexFinder oldFinder(m_model, change.oldPath);
         oldList << oldFinder.getIndex();
     }
@@ -923,7 +916,7 @@ void ModelLayoutChangeCommand::doCommand()
     }
 
     QModelIndexList newList;
-    for (const PersistentChange &change : qAsConst(m_changes)) {
+    for (const PersistentChange &change : std::as_const(m_changes)) {
         const IndexFinder newFinder(m_model, change.newPath);
         newList << newFinder.getIndex();
     }
@@ -933,3 +926,4 @@ void ModelLayoutChangeCommand::doCommand()
     m_model->layoutChanged();
 }
 
+#include "moc_dynamictreemodel.cpp"
